==> jc-1.4.0.tar.gz: javax/swing/text/Utilities.h <==
// public class javax.swing.text.Utilities

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 25e4f24c97e4556b javax_swing_text_Utilities

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_Utilities_H_
#define _JC_javax_swing_text_Utilities_H_

// Forward structure declarations
struct _jc_java_awt_FontMetrics$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Segment$object;
struct _jc_javax_swing_text_TabExpander$object;

// Typedefs
typedef struct _jc_javax_swing_text_Utilities$sub_refs	_jc_javax_swing_text_Utilities$sub_refs;
typedef struct _jc_javax_swing_text_Utilities$sub_nonrefs	_jc_javax_swing_text_Utilities$sub_nonrefs;
typedef struct _jc_javax_swing_text_Utilities$refs	_jc_javax_swing_text_Utilities$refs;
typedef struct _jc_javax_swing_text_Utilities$nonrefs	_jc_javax_swing_text_Utilities$nonrefs;
typedef struct _jc_javax_swing_text_Utilities$object	_jc_javax_swing_text_Utilities$object;

typedef struct _jc_javax_swing_text_Utilities$fields_struct	_jc_javax_swing_text_Utilities$fields_struct;
typedef const struct _jc_javax_swing_text_Utilities$vmethods	_jc_javax_swing_text_Utilities$vmethods;
typedef const struct _jc_javax_swing_text_Utilities$vtable	_jc_javax_swing_text_Utilities$vtable;
typedef const struct _jc_javax_swing_text_Utilities$vtype	_jc_javax_swing_text_Utilities$vtype;

// Class fields structure
struct _jc_javax_swing_text_Utilities$fields_struct {
	jint	BUF__5fLENGTH;
};
extern _jc_javax_swing_text_Utilities$fields_struct _jc_javax_swing_text_Utilities$class_fields;

// Constructors
extern void _jc_javax_swing_text_Utilities$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_Utilities$object *);

// Static methods
extern jint _jc_javax_swing_text_Utilities$method$drawTabbedText$9fef167999091459(_jc_env *, struct _jc_javax_swing_text_Segment$object *, jint, jint, struct _jc_java_awt_Graphics$object *, struct _jc_object *, jint);
extern jint _jc_javax_swing_text_Utilities$method$getTabbedTextWidth$742bf9e6b67dd9c2(_jc_env *, struct _jc_javax_swing_text_Segment$object *, struct _jc_java_awt_FontMetrics$object *, jint, struct _jc_object *, jint);

// Virtual methods structure
struct _jc_javax_swing_text_Utilities$vmethods {
};

// Vtable
struct _jc_javax_swing_text_Utilities$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_Utilities$vmethods	javax_swing_text_Utilities;
};

// Vtype
struct _jc_javax_swing_text_Utilities$vtype {
	_jc_type			type;
	_jc_javax_swing_text_Utilities$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_Utilities$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_Utilities$refs {
    _jc_javax_swing_text_Utilities$sub_refs	javax_swing_text_Utilities;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_Utilities$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_Utilities$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_Utilities$sub_nonrefs	javax_swing_text_Utilities;
};

// Object instance structure
struct _jc_javax_swing_text_Utilities$object {
	_jc_javax_swing_text_Utilities$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_Utilities$vtype	*vtype;
	_jc_javax_swing_text_Utilities$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_Utilities$vtype _jc_javax_swing_text_Utilities$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_Utilities, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_Utilities$class_object;

#endif	/* _JC_javax_swing_text_Utilities_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/Utilities.h <==
// public class javax.swing.text.Utilities

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 25e4f24c97e4556b javax_swing_text_Utilities

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_Utilities_H_
#define _JC_javax_swing_text_Utilities_H_

// Forward structure declarations
struct _jc_java_awt_FontMetrics$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Segment$object;
struct _jc_javax_swing_text_TabExpander$object;

// Typedefs
typedef struct _jc_javax_swing_text_Utilities$sub_refs	_jc_javax_swing_text_Utilities$sub_refs;
typedef struct _jc_javax_swing_text_Utilities$sub_nonrefs	_jc_javax_swing_text_Utilities$sub_nonrefs;
typedef struct _jc_javax_swing_text_Utilities$refs	_jc_javax_swing_text_Utilities$refs;
typedef struct _jc_javax_swing_text_Utilities$nonrefs	_jc_javax_swing_text_Utilities$nonrefs;
typedef struct _jc_javax_swing_text_Utilities$object	_jc_javax_swing_text_Utilities$object;

typedef struct _jc_javax_swing_text_Utilities$fields_struct	_jc_javax_swing_text_Utilities$fields_struct;
typedef const struct _jc_javax_swing_text_Utilities$vmethods	_jc_javax_swing_text_Utilities$vmethods;
typedef const struct _jc_javax_swing_text_Utilities$vtable	_jc_javax_swing_text_Utilities$vtable;
typedef const struct _jc_javax_swing_text_Utilities$vtype	_jc_javax_swing_text_Utilities$vtype;

// Class fields structure
struct _jc_javax_swing_text_Utilities$fields_struct {
	jint	BUF__5fLENGTH;
};
extern _jc_javax_swing_text_Utilities$fields_struct _jc_javax_swing_text_Utilities$class_fields;

// Constructors
extern void _jc_javax_swing_text_Utilities$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_Utilities$object *) _JC_JCNI_ATTR;

// Static methods
extern jint _jc_javax_swing_text_Utilities$method$drawTabbedText$9fef167999091459(_jc_env *, struct _jc_javax_swing_text_Segment$object *, jint, jint, struct _jc_java_awt_Graphics$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_Utilities$method$getTabbedTextWidth$742bf9e6b67dd9c2(_jc_env *, struct _jc_javax_swing_text_Segment$object *, struct _jc_java_awt_FontMetrics$object *, jint, struct _jc_object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_Utilities$vmethods {
};

// Vtable
struct _jc_javax_swing_text_Utilities$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_Utilities$vmethods	javax_swing_text_Utilities;
};

// Vtype
struct _jc_javax_swing_text_Utilities$vtype {
	_jc_type			type;
	_jc_javax_swing_text_Utilities$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_Utilities$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_Utilities$refs {
    _jc_javax_swing_text_Utilities$sub_refs	javax_swing_text_Utilities;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_Utilities$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_Utilities$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_Utilities$sub_nonrefs	javax_swing_text_Utilities;
};

// Object instance structure
struct _jc_javax_swing_text_Utilities$object {
	_jc_javax_swing_text_Utilities$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_Utilities$vtype	*vtype;
	_jc_javax_swing_text_Utilities$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_Utilities$vtype _jc_javax_swing_text_Utilities$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_Utilities, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_Utilities$class_object;

#endif	/* _JC_javax_swing_text_Utilities_H_ */
